@@ -2,7 +2,7 @@ package Time::Seconds;
 use strict;
 use vars qw/@EXPORT @EXPORT_OK/;
 
-our $VERSION = '1.25_01';
+our $VERSION = '1.29';
 
 use Exporter 5.57 'import';
 
@@ -12,9 +12,7 @@ use Exporter 5.57 'import';
     ONE_DAY 
     ONE_WEEK 
     ONE_MONTH
-    ONE_REAL_MONTH
     ONE_YEAR
-    ONE_REAL_YEAR
     ONE_FINANCIAL_MONTH
     LEAP_YEAR 
     NON_LEAP_YEAR
@@ -27,9 +25,7 @@ use constant ONE_HOUR => 3_600;
 use constant ONE_DAY => 86_400;
 use constant ONE_WEEK => 604_800;
 use constant ONE_MONTH => 2_629_744; # ONE_YEAR / 12
-use constant ONE_REAL_MONTH => '1M';
 use constant ONE_YEAR => 31_556_930; # 365.24225 days
-use constant ONE_REAL_YEAR  => '1Y';
 use constant ONE_FINANCIAL_MONTH => 2_592_000; # 30 days
 use constant LEAP_YEAR => 31_622_400; # 366 * ONE_DAY
 use constant NON_LEAP_YEAR => 31_536_000; # 365 * ONE_DAY
@@ -160,7 +156,7 @@ sub pretty {
         if ($s >= ONE_HOUR) {
             if ($s >= ONE_DAY) {
                 my $days = sprintf("%d", $s->days); # does a "floor"
-                $str = $days . " days, ";
+                $str .= $days . " days, ";
                 $s -= ($days * ONE_DAY);
             }
             my $hours = sprintf("%d", $s->hours);
